<?php

/**
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many individuals
 * and is licensed under the LGPL. For more information please see
 * <http://phing.info>.
 */

namespace Phing\Task\System\Condition;

use Phing\Exception\BuildException;
use Phing\Util\SizeHelper;

/**
 * Condition returns true if selected partition has the requested space, false otherwise.
 *
 * @author  Siad Ardroumli <siad.ardroumli@gmail.com>
 */
class HasFreeSpaceCondition implements Condition
{
    /**
     * @var string
     */
    private $partition;

    /**
     * @var string
     */
    private $needed;

    /**
     * {@inheritdoc}
     *
     * @throws BuildException
     *
     * @return bool
     */
    public function evaluate()
    {
        $this->validate();

        $free = disk_free_space($this->partition);

        return $free >= SizeHelper::fromHumanToBytes($this->needed);
    }

    /**
     * Set the partition/device to check.
     */
    public function setPartition(string $partition)
    {
        $this->partition = $partition;
    }

    /**
     * Set the amount of free space required.
     */
    public function setNeeded(string $needed)
    {
        $this->needed = $needed;
    }

    /**
     * @throws BuildException
     */
    private function validate()
    {
        if (null == $this->partition) {
            throw new BuildException('Please set the partition attribute.');
        }
        if (null == $this->needed) {
            throw new BuildException('Please set the needed attribute.');
        }
    }
}
